@@ -1,4 +1,4 @@
-from jiange.log import logger
+from jiange.log import LogAgent
 from jiange.file import dump_json
 
 
@@ -6,6 +6,7 @@ class AgentBase(object):
 
     def __init__(self, *args, **kwargs):
         self.skill_name = None
+        self.log = LogAgent()
 
     def dispatch(self, *args, **kwargs):
         raise NotImplementedError
@@ -32,11 +33,9 @@ class AgentBase(object):
             'skill_name': self.skill_name
         }
         body = dump_json(body, indent=False)
-        logger.info(body)
+        self.log.info(body)
 
     def log_info(self, body):
         if isinstance(body, dict):
             body = dump_json(body, indent=False)
-            logger.info(body)
-        else:
-            logger.info(body)
+        self.log.info(body)
