@@ -56,4 +56,4 @@ def get_interval_days(year, month, day):
 
 
 if __name__ == '__main__':
-    print(get_time_string())
+    print('time')
\ No newline at end of file
